@@ -10,7 +10,7 @@ use Lingua::AR::Word::Stem;	#needed to find the stem
 use Lingua::AR::Word::Encode;	#needed to encode into ArabTeX
 
 
-our $VERSION = '1.5.3';
+our $VERSION = '1.5.4';
 
 
 sub new{
@@ -58,9 +58,9 @@ Lingua::AR::Word - Perl extension for getting the stem and ArabTeX encoding of A
 	use utf8;
 	use Lingua::AR::Word;
 
-	my $word=Lingua::AR::Word->new(ARABIC_WORD_IN_UTF8);
+	my $word=Lingua::AR::Word->new("ARABIC_WORD_IN_UTF8");
 
-	open FOUTPUT, ">>:utf8" TEST" or die "Cannot create TEST: $!\n";
+	open FOUTPUT, ">>:utf8", "output" or die "Cannot create output file: $!\n";
 	
 
 	print FOUTPUT $word->get_word();
@@ -75,7 +75,6 @@ Lingua::AR::Word - Perl extension for getting the stem and ArabTeX encoding of A
 In order to work on an Arabic word, you need to create the object Lingua::AR::Word, passing the Arabic word encoded in utf8 to the constructor.
 You will then be able to get the stem through get_stem().
 You will get the ArabTeX translittered form through get_arabtex().
-If you also want the translation, you'll need to create the $db object (described in the Lingua::AR::Db module), so that it may look for its meaning in the correct Database.
 
 Remember that input-output directly to shell will not be useful as long as your shell doesn't support utf8 encoded characters.
 In the example above, for example, I piped the output to another file forcing its writing in utf8.
@@ -84,6 +83,7 @@ In the example above, for example, I piped the output to another file forcing it
 
 =head1 SEE ALSO
 
+If you also want the translation, check out the Lingua::AR::Db module.
 You may find more info about ArabTeX encoding at ftp://ftp.informatik.uni-stuttgart.de/pub/arabtex/arabtex.htm
 
 
